@@ -45,8 +45,7 @@ CONFIG_FILE_NAME = ".pyradrc"
 DEFAULT_CONFIG = '''# v0.1 keep this line!
 [
     ("''' + CENTER_ICON + '''", None), # the center item: (icon, action); action == None means "quit"
-    ("konsole","konsole"), ("kontact","kontact"),
-("konqueror","konqueror"), ("wesnoth","wesnoth"), # normal items
+    ("konsole","konsole"), ("kontact","kontact"), ("konqueror","konqueror"), ("wesnoth-icon","wesnoth"), # normal items
     ("krita","""[("''' + CENTER_ICON + '''", None), ("amarok", "amarok"), ("gimp","gimp")]""") # a folder with the center icon and only one real item
 ]
 '''
